bioneuralnet.downstream\_task
=============================

.. automodule:: bioneuralnet.downstream_task

   
   .. rubric:: Classes

   .. autosummary::
   
      DPMON
      SubjectRepresentation
   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   dpmon
   subject_representation
